@@ -124,6 +124,7 @@ userconfig::userconfig(const std::string& name,
     , max_ambiguous_bases(1000)
     , preserve5p(false)
     , collapse(false)
+    , collapse_conservatively(false)
     , deterministic(false)
     , shift(2)
     , seed(get_seed())
@@ -151,7 +152,6 @@ userconfig::userconfig(const std::string& name,
     , trim5p()
     , trim3p()
 {
-    argparser.add_header("OPTIONS:");
     argparser["--file1"] =
         new argparse::many(&input_files_1, "FILE [FILE ...]",
             "Input files containing mate 1 reads or single-ended reads; "
@@ -388,7 +388,16 @@ userconfig::userconfig(const std::string& name,
             "one of two different overlapping bases if these have the same "
             "quality (otherwise it picks the highest quality base). With "
             "--collapse-deterministic, AdapterRemoval will instead set such "
-            "bases to N. This option implies --collapse [default: %default].");
+            "bases to N. Setting this option also sets--collapse "
+            "[default: %default].");
+    argparser["--collapse-conservatively"] =
+        new argparse::flag(&collapse_conservatively,
+            "Enables a more conservative merging algorithm inspired by fastq-join, "
+            "in which the higher quality score is picked for matching bases and the "
+            "max score minus the min score is picked for mismatching bases. For more "
+            "details, see the documentation. --seed and --collapse-deterministic "
+            "have no effect when this is enabled. Setting this option also sets "
+            "--collapse [default: %default].");
     argparser["--minalignmentlength"] =
         new argparse::knob(&min_alignment_length, "LENGTH",
             "If --collapse is set, paired reads must overlap at least this "
@@ -445,6 +454,8 @@ argparse::parse_result userconfig::parse_args(int argc, char *argv[])
 
     // --collapse-deterministic implies --collapse
     collapse |= deterministic;
+    // --collapse-conservatively implies --collapse
+    collapse |= collapse_conservatively;
 
     quality_input_fmt = select_encoding("--qualitybase", quality_input_base, quality_max);
     if (!quality_input_fmt.get()) {
@@ -649,7 +660,7 @@ bool userconfig::is_good_alignment(const alignment_info& alignment) const
     const size_t n_aligned = static_cast<size_t>(alignment.length - alignment.n_ambiguous);
     size_t mm_threshold = static_cast<size_t>(mismatch_threshold * n_aligned);
 
-    if (n_aligned < min_adapter_overlap) {
+    if (n_aligned < min_adapter_overlap && !paired_ended_mode) {
         return false;
     }
 
